/*
 *
 * django-codenerix-invoicing
 *
 * Codenerix GNU
 *
 * Project URL : http://www.codenerix.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var controller = 'codenerixSalesSubListPackCtrl';
// var controller = undefined;
var custom_app_router = {};

if (typeof(tabs_js)!='undefined') {
    angular.forEach(tabs_js, function(tab, i){
        custom_app_router['details0.sublist' + tab.internal_id + ''] = ['/sublist' + tab.internal_id + '/:listid/', get_static('sales/partials/list_pack.html'), controller];
        if (typeof(tab.static_partial_row)!="undefined"){
            custom_app_router['details0.sublist' + tab.internal_id + '.rows'] = [null, tab.static_partial_row, null];
        }
    });
}

custom_app_router['details0.sublist'] = ['/sublist/0/', get_static('sales/partials/list_pack.html'), controller];

var module = codenerix_builder(
    ['codenerixSalesControllers'],
    custom_app_router
);
