# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-27 07:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0011_auto_20180202_0826'),
        ('codenerix_invoicing', '0013_salesorderdocument_removed'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='purchaseslinealbaran',
            name='product_unique',
        ),
        migrations.AddField(
            model_name='purchaseslinealbaran',
            name='product_unique',
            field=models.ManyToManyField(related_name='line_albaran_purchases', to='codenerix_products.ProductUnique', verbose_name='Product Unique'),
        ),
    ]
