# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-05-15 10:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0018_salesalbaran_send'),
    ]

    operations = [
        migrations.AddField(
            model_name='saleslines',
            name='discounts_basket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Discounts'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='discounts_invoice',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Discounts'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='discounts_order',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Discounts'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='discounts_ticket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Discounts'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='equivalence_surcharges_basket',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='equivalence_surcharges_invoice',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='equivalence_surcharges_order',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='equivalence_surcharges_ticket',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='subtotal_basket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Subtotal'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='subtotal_invoice',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Subtotal'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='subtotal_order',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Subtotal'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='subtotal_ticket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Subtotal'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='taxes_basket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Taxes'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='taxes_invoice',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Taxes'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='taxes_order',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Taxes'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='taxes_ticket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Taxes'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='total_basket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Total'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='total_invoice',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Total'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='total_order',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Total'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='total_ticket',
            field=models.DecimalField(decimal_places=2, default=0, editable=False, max_digits=10, verbose_name='Total'),
        ),
    ]
