# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-05-15 11:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0019_auto_20180515_1235'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='saleslines',
            name='discounts',
        ),
        migrations.RemoveField(
            model_name='saleslines',
            name='equivalence_surcharges',
        ),
        migrations.RemoveField(
            model_name='saleslines',
            name='subtotal',
        ),
        migrations.RemoveField(
            model_name='saleslines',
            name='taxes',
        ),
        migrations.RemoveField(
            model_name='saleslines',
            name='total',
        ),
    ]
