# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-07-08 05:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0021_auto_20180523_1036'),
    ]

    operations = [
        migrations.AlterField(
            model_name='salesorder',
            name='status_order',
            field=models.CharField(choices=[('PE', 'Pending'), ('PA', 'Payment accepted'), ('SE', 'Sent'), ('DE', 'Delivered'), ('CA', 'Cancelled')], default='PE', max_length=2, verbose_name='Status'),
        ),
    ]
