# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-27 08:00
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0014_auto_20180227_0858'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='purchaseslinealbaran',
            name='product_unique',
        ),
    ]
