{% extends extends_path %}
{% load static %}
{% load i18n %}
{% load codenerix_common %}
{% comment %}

django-codenerix-invoicing

Codenerix GNU

Project URL : http://www.codenerix.com

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

{% endcomment %}
{% block modal_title %}{% endblock %}

{% block modal_content %}

<style>
    @page {
        size: a4 portrait;
        @frame header_frame {           /* Static Frame */
            -pdf-frame-content: header_content;
            left: 50pt; width: 512pt; top: 40pt; height: 40pt;
        }
        @frame content_frame {          /* Content Frame */
            left: 50pt; width: 512pt; top: 90pt; height: 652pt;
        }
        @frame footer_frame {           /* Another static Frame */
            -pdf-frame-content: footer_content;
            left: 50pt; width: 512pt; top: 772pt; height: 40pt;
        }


    }
</style>







<table class="c-product-compare-table c-factura-print">
	<thead>
		<tr>
            <th align="left" colspan="2" class="c-compare-info c-bg-white">
                <img src="{{media_root}}{{corporate_image.company_logo}}" style="width: 250px" class="c-print-logo">
                <h1>Cambiar</h1>
            </th>
            <th class="">
                <p><strong>{{ corporate_image.business_name }}</strong></p>
                <p><strong>{% trans "CIF:" %} {{customer.external.nid}}</strong></p>
                <p>{% trans "Dirección:" %}</p>
                <p>{{budget.customer.external.address}}</p>
                <p>{% trans "Teléfono:" %}</p>
                <p>{{budget.customer.external.phone}}</p>
            </th>
            <th class="c-print-encabezado">
                <h1 class="c-font-uppercase c-font-bold c-theme-font">{% trans "BUDGTE" %}</h1>
                <h2>{% trans "Número" %}</h2>
                <p>{{budget.code}}</p>
                <h4>{% trans "Fecha" %}</h4>
                <p>{{budget.date}}</p>
            </th>
        </tr>
        <tr>
            <td>
                <h2>{% trans "Detalles del Producto"%}</h2>
            </td>
            <td class="c-compare-item">
                <h2>{% trans "Cantidad" %}</h2>
            </td>
            <td class="c-compare-item">
                <h2>{% trans "Precio" %}</h2>
            </td>
             <td class="c-compare-item">
                <h2>{% trans "Importe" %}</h2>
            </td>
        </tr>
    </thead>
    <tbody>
    	{% for lbs in line_budget_purchases %}
        <tr>
            <td class="c-compare-info"> {{lbs.product}}</td>
            <td class="c-compare-item"> {{lbs.quantity}}</td>
            <td class="c-compare-item"> {{lbs.price}} </td>
            <td class="c-compare-item"> {{lbs.total}}</td>
        </tr>
        {% endfor %}

    </tbody>
    <tfoot>
        <tr>
            <td>&nbsp;</td>
            <td>&nbsp;</td>
            <td>&nbsp;</td>
            <td class="c-compare-item"> <h4 class="c-font-bold c-theme-font">{% trans "TOTAL" %}</h4> </td>
        </tr>
        	<tr><td>&nbsp;</td>
            <td>&nbsp;</td>
            <td>&nbsp;</td>
            <td class="c-compare-item"> <h4 class="c-font-bold c-theme-font">{{total_budget}}</h4> </td>
        </tr>
        <tr>
            <td colspan="2" class="c-factura-print-40">
                <p><strong>{% trans "Dirección de Facturación:" %}</strong> </p>
                <p>{{budget.customer.external.address}} </p>
            </td>
            <td colspan="2" class="c-factura-print-40">
                <p><strong>{% trans "Dirección de Envío:" %}</strong> </p>
                <p>{{send_address.address}}, {{send_address.city.name}}, {{send_address.country.name}} </p>
            </td>
        </tr>
        <tr>
            <td colspan="4" class="c-factura-print-40">
                <p><strong>{% trans "Nota" %}:</strong> {{budget.observations | nicenull }} </p>
            </td>
        </tr>

    </tfoot>
</table>
{% endblock %}
