{% extends "codenerix/addmodal.html" %}
{% load i18n %}
{% load codenerix_lists %}
{% load codenerix_common %}
{% comment %}

django-codenerix-invoicing

Codenerix GNU

Project URL : http://www.codenerix.com

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

{% endcomment %}


{% block form_head %}
    <div class="modal-header">
        <h3 class="modal-title text-center">{% trans "Adding new" %} {{form.get_name}}</h3>
    </div>
    <div class="row clearfix">
    <div class="modal-body">
{% endblock %}

{% block extra_form_top %}{% endblock %}

{% block extra_form_bottom %}
    {# following div contains the simply detail view #}
    
    <div class="col-sm-12 col-md-12 col-lg-12">
        <div id="tabs" ng-controller="SublistCtrl">
        
            <uib-tabset class="hidden-xs hidden-sm">
            {% for tab in tabs %}
                <uib-tab ng-click="onClickTab('{% url tab.ws object.id %}')">
                    <uib-tab-heading>
                        <span>
                        {{tab.name}}{#<span class="badge">{{x}}</span>#}
                        </span>
                    </uib-tab-heading>
                    
                    <div ng-init="onClickTab('{% url tabs.0.ws object.id %}')" ng-include="currentTab"></div>
                </uib-tab>
            {% endfor %}
            </uib-tabset>
            
        </div>
    </div>
{% endblock %}