# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-29 11:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0005_auto_20180129_1211'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='p',
            name='a',
        ),
        migrations.RemoveField(
            model_name='p',
            name='f',
        ),
        migrations.RemoveField(
            model_name='p',
            name='p',
        ),
        migrations.RemoveField(
            model_name='p',
            name='product_final',
        ),
        migrations.RemoveField(
            model_name='saleslines',
            name='price_recommended',
        ),
        migrations.AddField(
            model_name='saleslines',
            name='price_recommended_basket',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True, verbose_name='Recomended price base'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='price_recommended_invoice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True, verbose_name='Recomended price base'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='price_recommended_order',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True, verbose_name='Recomended price base'),
        ),
        migrations.AddField(
            model_name='saleslines',
            name='price_recommended_ticket',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True, verbose_name='Recomended price base'),
        ),
        migrations.DeleteModel(
            name='Al',
        ),
        migrations.DeleteModel(
            name='Fa',
        ),
        migrations.DeleteModel(
            name='P',
        ),
        migrations.DeleteModel(
            name='Pr',
        ),
    ]
