<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.customer }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.code }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.budget__code }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.date }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.storage }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
    }"
    ng-init='over=false'>
    <div ng-repeat="(key, label) in data.meta.gentranslate.status_order_next">
        <button
            ng-if="key==row.status_order && label"
            class="btn btn-sm status"
            ng-class="{'btn-default': !over, 'btn-info': over}"
            ng-click="order_status_next(row.pk); $event.stopPropagation();"
            ng-mouseover="over=true"
            ng-mouseleave="over=false">
                <span class="status_normal">{{ row.get_status_order_display }}</span>
                <span class="status_hover" ng-repeat="(key, label) in data.meta.gentranslate.status_order_next" ng-if="key==row.status_order">
                    {{ label }}
                </span>
        </button>
        <button
            class="btn btn-sm status btn-default"
            ng-click='$event.stopPropagation();'
            ng-if="key==row.status_order && !label">
                {{ row.get_status_order_display }}
        </button>
    </div>
</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.get_payment_detail_display }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.source }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.number_tracking }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.budget__address_delivery }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.budget__address_invoice }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
	CDNX_invoicing_order_cancelled: row.status_order=='CA',
}">{{ row.total|codenerix:'money_euro' }}</td>
