# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-29 11:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0006_auto_20180129_1256'),
    ]

    operations = [
        migrations.AlterField(
            model_name='saleslines',
            name='discount_invoice',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True, verbose_name='Discount (%)'),
        ),
        migrations.AlterField(
            model_name='saleslines',
            name='discount_order',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True, verbose_name='Discount (%)'),
        ),
        migrations.AlterField(
            model_name='saleslines',
            name='discount_ticket',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True, verbose_name='Discount (%)'),
        ),
        migrations.AlterField(
            model_name='saleslines',
            name='price_base_invoice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True, verbose_name='Price base'),
        ),
        migrations.AlterField(
            model_name='saleslines',
            name='price_base_order',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True, verbose_name='Price base'),
        ),
        migrations.AlterField(
            model_name='saleslines',
            name='price_base_ticket',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True, verbose_name='Price base'),
        ),
    ]
