# Generated by Django 4.0.4 on 2022-05-13 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0022_auto_20180708_0711'),
    ]

    operations = [
        migrations.AlterField(
            model_name='reasonmodification',
            name='enable',
            field=models.BooleanField(blank=True, default=True, verbose_name='Enable'),
        ),
    ]
