CDNX_INVOICING_PERMISSIONS = {}
CDNX_INVOICING_PERMISSIONS['customer'] = [
    'list_region',
    'list_salesalbaran',
    'list_salesbasket',
    'list_salesinvoice',
    'list_salesinvoicerectification',
    'list_salesorder',
    'list_salesticket',
    'list_salesticketrectification',
    'list_timezone',
    'list_typedocument',
    'list_typedocumenttexten',
    'list_typedocumenttextes',
    'list_billingseries',
    'list_city',
    'list_continent',
    'list_corporateimage',
    'list_country',
    'list_customer',
    'list_customerdocument',
    'list_legalnote',
    'list_personaddress',
    'list_productdocument',
    'list_province',
    'list_purchaseslineinvoice',
    'list_region',
    'list_salesbasket',
    'list_salesinvoice',
    'list_salesinvoicerectification',
    'list_salesorder',
    'list_salesticket',
    'list_salesticketrectification',
    'list_timezone',
    'list_typedocument',
    'list_typedocumenttexten',
    'list_typedocumenttextes',
]
CDNX_INVOICING_PERMISSIONS['provider'] = [
    'list_typedocument',
    'list_typedocumenttexten',
    'list_typedocumenttextes',
]
