# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-16 13:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0012_auto_20180201_1212'),
    ]

    operations = [
        migrations.AddField(
            model_name='salesorderdocument',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
    ]
